.. Hey Emacs, this is -*- rst -*-

   This file follows reStructuredText markup syntax; see
   http://docutils.sf.net/rst.html for more information.


`elasticluster.conf`
====================
.. automodule:: elasticluster.conf
   :members:

